/* CalfGrailsPlugin - http://gate.ac.uk/ - (c) Univ Shef - AGPL licenced */

import gate.calf.FileTree

class CalfGrailsPlugin {

  // the plugin version
  def version = "6.2-SNAPSHOT"

  // the version or versions of Grails the plugin is designed for
  def grailsVersion = "1.3.0 > *"

  // the other plugins this plugin depends on
  def dependsOn = [:]

  // resources that are excluded from plugin packaging
  def pluginExcludes = [
    "grails-app/views/error.gsp",
    "grails-app/conf/gate/calf/LocalhostFilters.groovy"
  ]

  // metadata
  def author = "Hamish Cunningham"
  def authorEmail = "somewhere@something.com"
  def title = "Calf: CoW lite"
  def description = '''\\
CoW lite: a Grails plugin that provides YAM generation stuff.
'''

  // URL to the plugin's documentation
  def documentation = "http://gate.ac.uk/gatewiki/calf/doc/"

  // license: one of 'APACHE', 'GPL2', 'GPL3'
  def license = "AGPL3"

  // details of company behind the plugin (if there is one)
  def organization = [ name: "University of Sheffield GATE Team", url: "http://gate.ac.uk/" ]

  // any additional developers beyond the author specified above.
  // def developers = [ [ name: "Joe Bloggs", email: "joe@bloggs.net" ]]

  // location of the plugin's issue tracker.
  // def issueManagement = [ system: "JIRA", url: "http://jira.grails.org/browse/GPMYPLUGIN" ]

  // online location of the plugin's browseable source code.
  def scm = [ url: "https://gatewiki.svn.sourceforge.net/svnroot/gatewiki/trunk/calf" ]

  def doWithWebDescriptor = { xml ->
    // implement additions to web.xml (optional), this event occurs before 
  }

  def doWithSpring = {
    // implement runtime spring config (optional)
  }

  def doWithDynamicMethods = { ctx ->
    // implement registering dynamic methods to classes (optional)
  }

  /** Post initialization config: bootstrap default FileTree. */
  def doWithApplicationContext = { applicationContext ->
    // set up default FileTree if none exist
    FileTree.withTransaction { status ->
      List trees = FileTree.list()
      if(trees.size() == 0) {
        log.info("creating a default FileTree")

        FileTree tree = null
        String path = application.config.gate.calf.defaultTreePath
        log.info("default path = ${path}")

        if(path) {
          tree = new FileTree(
            isDefault: true, name: "default", description: "default tree",
            path: path, autoRegen: true
          )
        } else {
          tree = new FileTree(
            isDefault: true, name: "home", description: "user home directory",
            path: System.getProperty("user.home"), autoRegen: true
          )
        }

        if(! tree || ! tree.save() || tree.hasErrors())
          log.error("Couldn't create default FileTree: ${tree?.properties}")
        else
          log.info("default FileTree saved")
      }
    }
  } // doWithApplicationContext

  def onChange = { event ->
    // implement code that is executed when any artefact that this plugin is
    // watching is modified and reloaded. the event contains: event.source,
    // event.application, event.manager, event.ctx, and event.plugin.
  }

  def onConfigChange = { event ->
    // implement code that is executed when the project configuration
    // changes. the event is the same as for 'onChange'.
  }

  def onShutdown = { event ->
    // implement code that is executed when the application shuts down (optional)
  }
}
